==> sempubflow-0.0.1.tar.gz: sempubflow-0.0.1/README.md <==
# SemPubFlow

[![Join the discussion at https://github.com/WolfgangFahl/SemPubFlow/discussions](https://img.shields.io/github/discussions/WolfgangFahl/SemPubFlow)](https://github.com/WolfgangFahl/SemPubFlow/discussions) 
[![pypi](https://img.shields.io/pypi/pyversions/SemPubFlow)](https://pypi.org/project/SemPubFlow/)
[![Github Actions Build](https://github.com/WolfgangFahl/SemPubFlow/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/SemPubFlow/actions?query=workflow%3ABuild+branch%3Amain)
[![PyPI Status](https://img.shields.io/pypi/v/SemPubFlow.svg)](https://pypi.python.org/pypi/SemPubFlow/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/SemPubFlow.svg)](https://github.com/WolfgangFahl/SemPubFlow/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/SemPubFlow.svg)](https://github.com/WolfgangFahl/SemPubFlow/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/SemPubFlow.svg)](https://www.apache.org/licenses/LICENSE-2.0)

SemPubFlow is a metadata-first publishing pipeline designed to streamline the process of scientific publishing. 
The system is specifically tailored towards the needs of scientific outlets such as CEUR-WS, ACM, or DROPS.

## Features

* Metadata-driven: Simplifies the management and usage of metadata in scientific publishing.
* Common-Sense Approach: The pipeline is built with a practical, intuitive design, making it accessible and easy to use for researchers and publishers alike.
* Drag & Drop Support: Offers drag-and-drop functionality for PDFs and BibTeX files, streamlining the document upload process.
* Compatible: Designed to work seamlessly with popular scientific outlets such as CEUR-WS, ACM, or DROPS.

## Demo
http://sempubflow.bitplan.com/

## Installation

```bash
pip install sem-pub-flow
```

# Usage 
spf -h

==> sempubflow-0.0.2.tar.gz: sempubflow-0.0.2/README.md <==
# SemPubFlow

[![Join the discussion at https://github.com/WolfgangFahl/SemPubFlow/discussions](https://img.shields.io/github/discussions/WolfgangFahl/SemPubFlow)](https://github.com/WolfgangFahl/SemPubFlow/discussions) 
[![pypi](https://img.shields.io/pypi/pyversions/SemPubFlow)](https://pypi.org/project/SemPubFlow/)
[![Github Actions Build](https://github.com/WolfgangFahl/SemPubFlow/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/SemPubFlow/actions?query=workflow%3ABuild+branch%3Amain)
[![PyPI Status](https://img.shields.io/pypi/v/SemPubFlow.svg)](https://pypi.python.org/pypi/SemPubFlow/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/SemPubFlow.svg)](https://github.com/WolfgangFahl/SemPubFlow/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/SemPubFlow.svg)](https://github.com/WolfgangFahl/SemPubFlow/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/SemPubFlow.svg)](https://www.apache.org/licenses/LICENSE-2.0)

SemPubFlow is a metadata-first publishing pipeline designed to streamline the process of scientific publishing. 
The system is specifically tailored towards the needs of scientific outlets such as CEUR-WS, ACL Anthology, or DROPS.

## Features

* Metadata-driven: Simplifies the management and usage of metadata in scientific publishing.
* Common-Sense Approach: The pipeline is built with a practical, intuitive design, making it accessible and easy to use for researchers and publishers alike.
* Drag & Drop Support: Offers drag-and-drop functionality for PDFs and BibTeX files, streamlining the document upload process.
* Compatible: Designed to work seamlessly with popular scientific outlets such as CEUR-WS, ACM, or DROPS.

## Demo
http://sempubflow.bitplan.com/

## Installation

```bash
pip install sem-pub-flow
```

# Usage 
spf -h
